@@ -144,9 +144,9 @@ class TimedTask4AutoDealwithPost(TimedTaskBasic):
         elif(self.setting["whichKind"] == 'relativeParagraph'):
             rarp.run(setting=self.setting)
         elif(self.setting["whichKind"] == 'contentImgs'):
-            raci.run(proj_absPath=self.setting["proj_absPath"], oriDomain=self.setting["oriDomain"], database=self.setting['dbName'], tableNameList=self.setting['tableName'])
+            raci.run(proj_absPath=self.setting["proj_absPath"], oriDomain=self.setting["oriDomain"], database=self.setting['databaseName'], tableNameList=self.setting['tableName'])
         elif(self.setting["whichKind"] == 'thumbnailImgs'):
-            rati.run(proj_absPath=self.setting["proj_absPath"], oriDomain=self.setting["oriDomain"], database=self.setting['dbName'], tableNameList=self.setting['tableName'])
+            rati.run(proj_absPath=self.setting["proj_absPath"], oriDomain=self.setting["oriDomain"], database=self.setting['databaseName'], tableNameList=self.setting['tableName'])
         elif(self.setting["whichKind"]=='video'):
             rav.run_bilibili(setting=self.setting)
         print("上传数据完成，接下来清空数据库")
